; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

; Kamehame ha
[Command]
name = "kame"
command = ~D, DF, F, y+b
time = 30

; Kamehame Ha
[Command]
name = "kame1"
command = ~D, DF, F, y+b
time = 30

; Giga Cell Combination ( Meteor Attack )
[Command]
name = "GigaCell"
command = ~F, B, F, B, F, y
time = 90

; Giga Cell Combination ( Meteor Attack )
[Command]
name = "GigaCell2"
command = ~F, B, F, B, F, b
time = 90

; Giga Burn ( Meteor Attack )
[Command]
name = "GigaBurn"
command = ~D, DB, B, F, y
time = 30

; Giga Burn ( Meteor Attack )
[Command]
name = "GigaBurn2"
command = ~D, DB, B, F, b
time = 30

;-| Special Motions |------------------------------------------------------
;-----------------
; Cell Jr. Attack
[Command]
name = "Cell Jr. Attack"
command = ~F, B, F, x
time = 30

; Cell Jr. Attack ( 2 )
[Command]
name = "Cell Jr. Attack2"
command = ~F, B, F, a
time = 30

; Levitation
[Command]
name = "levi"
command = ~D, DB, B, y
time = 30

; mini Kame 
[Command]
name = "minikame"
command = ~D, DB, B, F, x
time = 30

; mini Kame 
[Command]
name = "minikame1"
command = ~D, DB, B, F, a
time = 30

; Negative Arrow 
[Command]
name = "negative"
command = ~D, DB, B, y
time = 30

; QCF
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

; katsuu energy dan
[Command]
name = "katsuu"
command = ~F, B, F, y
time = 30

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "fly"
command = y+x
time = 1

[Command]
name = "energy"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_yb"
command = /F, y+b
time = 1

[Command]
name = "back_yb"
command = /B, y+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_yb"
command = /y+b
time = 30

[Command]
name = "hold_xa"
command = /x+a
time = 30

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 30

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 30

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
; Hyper Kamehame Ha (level 1)
[State -1]
type = ChangeState
value = 3000
triggerall = command = "kame"
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
; Hyper Kamehame Ha (level 2)
[State -1]
type = ChangeState
value = 3000
triggerall = command = "kame1"
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
; Hyper Kamehame Ha (level 1) no ar
[State -1]
type = ChangeState
value = 3001
triggerall = command = "kame"
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = ctrl = 1
trigger1 = statetype != A
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Hyper Kamehame Ha (level 2)no ar
[State -1]
type = ChangeState
value = 3001
triggerall = command = "kame1"
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = ctrl = 1
trigger1 = statetype != A
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Giga Cell Combination ( Meteor Attack )
[State -1]
type = ChangeState
value = 4000
triggerall = command = "GigaCell"
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
; Giga Cell Combination ( Meteor Attack )
[State -1]
type = ChangeState
value = 4000
triggerall = command = "GigaCell2"
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
; Giga Burn ( Meteor Attack )
[State -1]
type = ChangeState
value = 4010
triggerall = command = "GigaBurn"
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
; Giga Burn ( Meteor Attack )
[State -1]
type = ChangeState
value = 4010
triggerall = command = "GigaBurn2"
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_b";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;---------------------------------------------------------------------------
; KI energizer
[State -1]
type = ChangeState
value = 700
triggerall = power < 3000
trigger1 = command = "hold_s"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; KI energizer ( no ar )
[State -1]
type = ChangeState
value = 702
triggerall = power < 3000
triggerall = command = "hold_s"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Voar 
[State -1]
type = ChangeState
value = 1800
triggerall = command = "fly"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Voar ( no ar)
[State -1]
type = ChangeState
value = 1900
triggerall = command = "fly"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Jogada
[State -1]
type = ChangeState
value = 800
trigger1 = command = "fwd_b"
trigger1 = statetype = S
trigger1 = stateno != 100
trigger1 = p2movetype != H
trigger1 = p2statetype != A
trigger1 = ctrl = 1
trigger1 = P2bodydist X <= 10

;---------------------------------------------------------------------------
; Energy Release
[State -1]
type = ChangeState
value = 2011
triggerall = command = "energy"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Giga Shoulder ( ou counter ) 
[State -1]
type = ChangeState
value = 1090
triggerall = command = "fwd_yb"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Giga Shoulder ( ou counter ) 
[State -1]
type = ChangeState
value = 1090
triggerall = command = "back_yb"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Levitation Slicer 
[State -1]
type = ChangeState
value = 825
triggerall = command = "levi"
triggerall = P2bodydist X >= 45
trigger1 = ctrl = 1
trigger1 = statetype = S

;---------------------------------------------------------------------------
; Cell Jr. Attack 
[State -1]
type = ChangeState
value = 1060
triggerall = command = "Cell Jr. Attack"
triggerall = P2Name != "Cell Jr."
triggerall = P4Name != "Cell Jr."
triggerall = NumHelper(1061) = 0
triggerall = NumHelper(1062) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Cell Jr. Attack (2)
[State -1]
type = ChangeState
value = 1060
triggerall = command = "Cell Jr. Attack2"
triggerall = P2Name != "Cell Jr."
triggerall = P4Name != "Cell Jr."
triggerall = NumHelper(1061) = 0
triggerall = NumHelper(1062) = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Cell Combo (B)
[State -1]
type = ChangeState
value = 1050
triggerall = command = "QCB_b"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Power Attack
[State -1]
type = ChangeState
value = 2010
triggerall = command = "QCF_b"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Energy Dan
[State -1]
type = ChangeState
value = 1000
triggerall = command = "QCF_y"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Energy Dan reto (no ar)
[State -1]
type = ChangeState
value = 1001
triggerall = command = "QCB_y"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Energy Dan para cima (no ar) 
[State -1]
type = ChangeState
value = 1002
triggerall = command = "QCF_y"
triggerall = P2Dist Y <= -20
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Energy Dan para baixo (no ar) 
[State -1]
type = ChangeState
value = 1003
triggerall = command = "QCF_y"
triggerall = P2Dist Y <= 3000
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Negative Arrow ( no pulo )
[State -1]
type = ChangeState
value = 1004
triggerall = command = "negative"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Katsuu Energy Dan
[State -1]
type = ChangeState
value = 1010
triggerall = command = "katsuu"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Katsuu Energy Dan ( no ar )
[State -1]
type = ChangeState
value = 1005
triggerall = command = "katsuu"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Cho Kamehame Ha 
[State -1]
type = ChangeState
value = 2000
triggerall = command = "minikame"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Cho Kamehame Ha 
[State -1]
type = ChangeState
value = 2000
triggerall = command = "minikame1"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Cho Kamehame Ha ( no voo )
[State -1]
type = ChangeState
value = 2002
triggerall = command = "minikame"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Cho Kamehame Ha ( no voo )
[State -1]
type = ChangeState
value = 2002
triggerall = command = "minikame1"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Kamehame Ha ( para cima )
[State -1]
type = ChangeState
value = 2001
triggerall = command = "QCF_x"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Kamehame Ha ( para cima )
[State -1]
type = ChangeState
value = 2001
triggerall = command = "QCF_a"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Kamehame Ha ( para cima no voo)
[State -1]
type = ChangeState
value = 2003
triggerall = command = "QCF_x"
triggerall = P2Dist Y <= -20
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Kamehame Ha ( para cima no voo)
[State -1]
type = ChangeState
value = 2003
triggerall = command = "QCF_a"
triggerall = P2Dist Y <= -20
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Kamehame Ha ( para baixo no voo)
[State -1]
type = ChangeState
value = 2004
triggerall = command = "QCF_x"
triggerall = P2Dist Y <= 3000
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; Kamehame Ha ( para baixo no voo)
[State -1]
type = ChangeState
value = 2004
triggerall = command = "QCF_a"
triggerall = P2Dist Y <= 3000
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; soco fraco (perto)
[State -1]
type = ChangeState
value = 201
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = P2bodydist X <= 6

; soco fraco
[State -1]
type = ChangeState
value = 200
triggerall = command = "y";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; chute fraco
[State -1]
type = ChangeState
value = 202
triggerall = command = "x";Place name of command here
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; soco forte (perto)
[State -1]
type = ChangeState
value = 204
trigger1 = command = "b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = P2bodydist X <= 6

; Soco forte
[State -1]
type = ChangeState
value = 205
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900
 
;---------------------------------------------------------------------------
; Chute forte
[State -1]
type = ChangeState
value = 203
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 1900

;---------------------------------------------------------------------------
; soco fraco abaixado
[State -1]
type = ChangeState
value = 400
triggerall = command = "y"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; chute fraco abaixado
[State -1]
type = ChangeState
value = 401
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; soco forte abaixado
[State -1]
type = ChangeState
value = 402
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; chute forte abaixado
[State -1]
type = ChangeState
value = 403
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; soco fraco no ar
[State -1]
type = ChangeState
value = 600
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; chute fraco no ar
[State -1]
type = ChangeState
value = 602
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Chute forte no ar
[State -1]
type = ChangeState
value = 603
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Soco forte no ar
[State -1]
type = ChangeState
value = 601
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
